# COS SDK — Python client for the Cognitive Operating System API
#
# Quick start:
#   from cos_sdk import COS
#   client = COS(api_key="cos_live_xxx")
#   result = client.validate("AI-generated text to check")
#   print(result.confidence_score, result.risk_level)

from cos_sdk.client import COS, AsyncCOS
from cos_sdk.models import ValidationResult, FlaggedClaim, ModelVerdict, StreamEvent
from cos_sdk.exceptions import (
    COSError, AuthenticationError, ForbiddenError,
    RateLimitError, ValidationError, ServerError,
)

__version__ = "0.1.0"
__all__ = [
    "COS",
    "AsyncCOS",
    "ValidationResult",
    "FlaggedClaim",
    "ModelVerdict",
    "StreamEvent",
    "COSError",
    "AuthenticationError",
    "ForbiddenError",
    "RateLimitError",
    "ValidationError",
    "ServerError",
]
